@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Muldis::D; # package
-    use version 0.74; our $VERSION = qv('0.51.0');
+    use version 0.74; our $VERSION = qv('0.52.0');
     # Note that Perl code only exists at all in this file in order to help
     # the CPAN indexer handle the distribution properly.
 } # package Muldis::D
@@ -29,7 +29,7 @@ Formal spec of Muldis D relational DBMS lang
 
 =head1 VERSION
 
-This document is Muldis::D version 0.51.0.
+This document is Muldis::D version 0.52.0.
 
 =head1 PREFACE
 
@@ -57,9 +57,9 @@ at them.
 
 The fully-qualified name of this multi-part document and the language
 specification it contains (as a single composition) is
-C<Muldis_D:'http://muldis.com':'0.51.0'>.  It is the official/original (not
+C<Muldis_D:'http://muldis.com':'0.52.0'>.  It is the official/original (not
 embraced and extended) Muldis D language specification by the authority
-Darren Duncan (C<http://muldis.com>), version C<0.51.0> (this number
+Darren Duncan (C<http://muldis.com>), version C<0.52.0> (this number
 matches the VERSION pod in this file).  This multi-part document is named
 and organized with the expectation that many dialects, extensions, and core
 versions of it will exist over time, some of those under the original
@@ -231,11 +231,11 @@ number, which identifies the base language spec version between all those
 by the same authority, typically indicating the relative ages of the
 versions, the relative sizes of their deltas, and perhaps which development
 branches the versions are on.  The base version number is a sequence of
-unsigned integers that consists of at least 1 element, and either 3 or 4
-elements is recommended (the official base version number has 3 elements);
-elements are ordered from most significant to least (eg, [major, minor,
-bug-fix]).  At the present time, the official spec version number to use is
-shown in the VERSION and DESCRIPTION pod of the current file, when
+non-negative integers that consists of at least 1 element, and either 3 or
+4 elements is recommended (the official base version number has 3
+elements); elements are ordered from most significant to least (eg, [major,
+minor, bug-fix]).  At the present time, the official spec version number to
+use is shown in the VERSION and DESCRIPTION pod of the current file, when
 corresponding to the spec containing that file.
 
 =head2 Dialect
